@@ -1,10 +1,10 @@
 /*
-**  L2 - OSSP Logging Library
+**  OSSP l2 - Logging Library
 **  Copyright (c) 2001-2002 The OSSP Project (http://www.ossp.org/)
 **  Copyright (c) 2001-2002 Cable & Wireless Deutschland (http://www.cw.com/de/)
 **
 **  This file is part of OSSP L2, a flexible logging library which
-**  can be found at http://www.ossp.org/pkg/l2/.
+**  can be found at http://www.ossp.org/pkg/lib/l2/.
 **
 **  Permission to use, copy, modify, and distribute this software for
 **  any purpose with or without fee is hereby granted, provided that
@@ -112,7 +112,7 @@ static l2_result_t expand_specials(char *buf, size_t bufsize, l2_level_t level)
                     break;
                 }
                 case 'N': {
-                    if (uname(&uts) == 0)
+                    if (uname(&uts) != -1)
                         l2_util_sprintf(caBuf, sizeof(caBuf), uts.nodename);
                     else
                         l2_util_sprintf(caBuf, sizeof(caBuf), "localhost");
